%define shortVersion %(echo %{version} | cut -d. -f1,2)
%define majorVersion %(echo %{version} | cut -d. -f1)

%bcond_with bootstrap

%ifarch i586
%bcond_with qt
%else
%bcond_without qt
%endif

%bcond_with tests

#comment out if not prerel
#define prerel rc4

#release for bumping
%define rel 1

Name:		cmake
Summary:	Cross-platform, open-source make system
Epoch:		1
Version:	3.29.4
Release:	%mkrel %{?prerel:0.%prerel.}%{rel}
License:	BSD
Group:		Development/Other
Url:		https://www.cmake.org/
Source0:	https://www.cmake.org/files/v%{shortVersion}/%{name}-%{version}%{?prerel:-%prerel}.tar.gz
# (ngompa) From Fedora -- fixes ruby detection in CMake
Patch0:         https://src.fedoraproject.org/rpms/cmake/raw/rawhide/f/cmake-findruby.patch
BuildRequires:	pkgconfig(libcrypto)
%if %{without bootstrap}
BuildRequires:	cmake
BuildRequires:	pkgconfig(bzip2)
BuildRequires:	pkgconfig(expat)
BuildRequires:	gcc-gfortran
BuildRequires:	pkgconfig(libidn)
BuildRequires:	pkgconfig(jsoncpp)
BuildRequires:	pkgconfig(libarchive)
BuildRequires:	pkgconfig(libcurl)
BuildRequires:	pkgconfig(libuv)
BuildRequires:	pkgconfig(ncurses)
BuildRequires:	perl
BuildRequires:	xz
BuildRequires:	pkgconfig(zlib)
BuildRequires:	rhash-devel

%if %{with qt}
BuildRequires:	cmake(Qt6Widgets)
%endif

%if %{with tests}
# Needed for test suite.
BuildRequires:	cxxtest
BuildRequires:	pkgconfig(Coin)
%endif

%endif

Requires:	rpm-mageia-setup
Requires:	%{name}-rpm-macros

Provides:	%{name}%{majorVersion} = %{version}-%{release}

%description
CMake is used to control the software compilation process using
simple platform and compiler independent configuration files.
CMake generates native makefiles and workspaces that can be
used in the compiler environment of your choice. CMake is quite
sophisticated: it is possible to support complex environments
requiring system configuration, pre-processor generation, code
generation, and template instantiation.

%files
%{_bindir}/cmake
%if ! %{with bootstrap}
%{_bindir}/ccmake
%endif
%{_bindir}/ctest
%{_bindir}/cpack
%{_datadir}/%{name}/
%{_datadir}/aclocal/cmake.m4
%{_datadir}/bash-completion/completions/*
%{_sysconfdir}/emacs/site-start.d/%{name}.el
%{_datadir}/vim/*/*
%{_datadir}/emacs/site-lisp/cmake-mode.el
%dir %{_libdir}/%{name}

#-----------------------------------------------------------------------------

%if %{without bootstrap}
%if %{with qt}
%package -n %{name}-qtgui
Summary:	Qt GUI Dialog for CMake - the Cross-platform, open-source make system
Group:		Development/Other
Requires:	%{name} = %{epoch}:%{version}-%{release}
Provides:	%{name}-gui = %{epoch}:%{version}-%{release}

%description -n %{name}-qtgui
CMake is used to control the software compilation process using
simple platform and compiler independent configuration files.

This is the Qt GUI.

%files -n %{name}-qtgui
%{_bindir}/cmake-gui
%{_datadir}/applications/cmake-gui.desktop
%{_datadir}/mime/packages/cmakecache.xml
%{_iconsdir}/*/*/*/*.png
%endif
%endif
#-----------------------------------------------------------------------------

%prep
%setup -q -n %{name}-%{version}%{?prerel:-%prerel}
%autopatch -p1

# Don't try to automagically find files in /usr/X11R6
# But also don't change a prefix if it is not /usr
perl -pi -e 's@^\s+/usr/X11R6/.*\n@@' Modules/*.cmake

%ifarch %arm
# bootstrap test is taking ages on arm
sed -i -e 's!SET(CMAKE_LONG_TEST_TIMEOUT 1500)!SET(CMAKE_LONG_TEST_TIMEOUT 7200)!g' Tests/CMakeLists.txt
%endif

%build
%if %{with bootstrap}
mkdir -p %{_vpath_builddir}
cd %{_vpath_builddir}
%set_build_flags
../configure \
    --no-system-libs \
    --parallel="%_smp_mflags" \
    --prefix=%{_prefix} \
    --datadir=/share/%{name} \
    --mandir=/share/man \
    --docdir=/share/doc/%{name}
%make_build
%else
%cmake \
    -DCMAKE_USE_SYSTEM_LIBRARIES:BOOL=ON \
    -DCMake_ENABLE_DEBUGGER:BOOL=OFF \
    -DCMAKE_DATA_DIR:PATH=/share/%{name} \
    -DCMAKE_MAN_DIR:PATH=/share/man \
    -DCMAKE_DOC_DIR:PATH=/share/doc/%{name} \
    -DBUILD_QtDialog:BOOL=%{?with_qt:ON}%{?!with_qt:OFF}
%cmake_build
%endif

%install
%make_install -C %{_vpath_builddir}

# cmake mode for emacs
install -d %{buildroot}%{_sysconfdir}/emacs/site-start.d
cat <<EOF >%{buildroot}%{_sysconfdir}/emacs/site-start.d/%{name}.el
(setq load-path (cons (expand-file-name "/dir/with/cmake-mode") load-path))
(require 'cmake-mode)
(setq auto-mode-alist
      (append '(("CMakeLists\\\\.txt\\\\'" . cmake-mode)
                ("\\\\.cmake\\\\'" . cmake-mode))
              auto-mode-alist))
EOF

# Create/Own this dir as this is used in cmake dependant rpms but not own by any
mkdir -p %{buildroot}%{_libdir}/%{name}

# There are some stray Copyright.txt files there sometimes.
rm -fr %{buildroot}%{_docdir}/%{name}/

%if %{with tests}
%check
unset DISPLAY
cd %{_vpath_builddir}
bin/ctest -V -E ModuleNotices -E 'CMake.(HTML|FileDownload)' -E CTestTestUpload %{?_smp_mflags}
%endif


%changelog
* Tue Jun 04 2024 kekepower <kekepower> 1:3.29.4-1.mga10
+ Revision: 2069647
- Update to version 3.29.4

* Tue May 07 2024 kekepower <kekepower> 1:3.29.3-1.mga10
+ Revision: 2062823
- Update to version 3.29.3

* Fri Apr 12 2024 kekepower <kekepower> 1:3.29.2-1.mga10
+ Revision: 2056677
- Update to versin 3.29.2

* Fri Apr 05 2024 wally <wally> 1:3.29.1-1.mga10
+ Revision: 2054493
- build i586 without qt
+ kekepower <kekepower>
- Update to version 3.29.1

* Thu Mar 21 2024 kekepower <kekepower> 1:3.29.0-1.mga10
+ Revision: 2051249
- Update to version 3.29.0 final

* Mon Mar 18 2024 kekepower <kekepower> 1:3.29.0-0.rc4.1.mga10
+ Revision: 2050382
- Update to version 3.29.0-rc4

* Tue Mar 05 2024 kekepower <kekepower> 1:3.29.0-0.rc3.1.mga10
+ Revision: 2047631
- Update to version 3.29.0-rc3

* Thu Feb 22 2024 kekepower <kekepower> 1:3.29.0-0.rc2.1.mga10
+ Revision: 2043292
- Update to version 3.29.0-rc2

* Fri Feb 16 2024 kekepower <kekepower> 1:3.29.0-0.rc1.1.mga10
+ Revision: 2041944
- Update to version 3.29.0-rc1

* Tue Feb 06 2024 kekepower <kekepower> 1:3.28.3-1.mga10
+ Revision: 2037541
- Update to version 3.28.3

* Thu Dec 14 2023 kekepower <kekepower> 1:3.28.1-1.mga10
+ Revision: 2018178
- Update to version 3.28.1

* Wed Dec 06 2023 kekepower <kekepower> 1:3.28.0-1.mga10
+ Revision: 2013896
- Update to version 3.28.0 final

* Fri Dec 01 2023 kekepower <kekepower> 1:3.28.0-0.rc6.1.mga10
+ Revision: 2012005
- Update to version 3.28.0-rc6

* Wed Nov 15 2023 kekepower <kekepower> 1:3.28.0-0.rc5.1.mga10
+ Revision: 2007100
- Update to version 3.28.0-rc5

* Tue Nov 07 2023 kekepower <kekepower> 1:3.28.0-0.rc4.1.mga10
+ Revision: 2004983
- Update to version 3.28.0-rc4

* Sun Oct 29 2023 kekepower <kekepower> 1:3.28.0-0.rc3.1.mga10
+ Revision: 2002714
- Update to version 3.28.0-rc3

* Sun Oct 29 2023 daviddavid <daviddavid> 1:3.27.7-4.mga10
+ Revision: 2002564
- rebuild for new jsoncpp 1.9.5

* Fri Oct 27 2023 daviddavid <daviddavid> 1:3.27.7-3.mga10
+ Revision: 2002043
- rebuild for new rhash 1.4.4

* Tue Oct 24 2023 daviddavid <daviddavid> 1:3.27.7-2.mga10
+ Revision: 2000761
- switch cmake-gui to Qt6

* Mon Oct 09 2023 kekepower <kekepower> 1:3.27.7-1.mga10
+ Revision: 1993753
- Update to version 3.27.7

* Mon Sep 25 2023 wally <wally> 1:3.27.6-1.mga10
+ Revision: 1990915
- new version 3.27.6
- disable debugger until we have cppdap

* Wed Sep 13 2023 ngompa <ngompa> 1:3.26.5-2.mga10
+ Revision: 1986393
- Add patch from Fedora to fix FindRuby module

* Mon Aug 28 2023 kekepower <kekepower> 1:3.26.5-1.mga10
+ Revision: 1980680
- Update to version 3.26.5

* Sun May 21 2023 kekepower <kekepower> 1:3.26.4-1.mga9
+ Revision: 1957519
- Update to version 3.26.4

* Wed Apr 05 2023 kekepower <kekepower> 1:3.26.3-1.mga9
+ Revision: 1951533
- Update to version 3.26.3

* Thu Mar 30 2023 kekepower <kekepower> 1:3.26.2-1.mga9
+ Revision: 1950819
- Update to version 3.26.2

* Fri Mar 24 2023 kekepower <kekepower> 1:3.26.1-1.mga9
+ Revision: 1950268
- Update to version 3.26.1

* Wed Mar 15 2023 kekepower <kekepower> 1:3.26.0-1.mga9
+ Revision: 1949042
- Update to version 3.26.0 final

* Thu Mar 09 2023 kekepower <kekepower> 1:3.26.0-0.rc6.1.mga9
+ Revision: 1948426
- Update to version 3.26.0-rc6

* Thu Mar 02 2023 kekepower <kekepower> 1:3.26.0-0.rc5.1.mga9
+ Revision: 1946227
- Update to version 3.26.0-rc5

* Wed Feb 22 2023 kekepower <kekepower> 1:3.26.0-0.rc4.1.mga9
+ Revision: 1944772
- Update to version 3.26.0-rc4

* Wed Feb 15 2023 kekepower <kekepower> 1:3.26.0-0.rc3.1.mga9
+ Revision: 1942764
- Update to version 3.26.0-rc3

* Thu Jan 19 2023 wally <wally> 1:3.25.2-1.mga9
+ Revision: 1934399
- new version 3.25.2

* Tue Dec 13 2022 ghibo <ghibo> 1:3.25.1-2.mga9
+ Revision: 1921615
- Rebuild against newer libarchive and librhash

* Wed Nov 30 2022 kekepower <kekepower> 1:3.25.1-1.mga9
+ Revision: 1913554
- Update to version 3.25.1

* Wed Nov 16 2022 kekepower <kekepower> 1:3.25.0-1.mga9
+ Revision: 1908074
- Update to version 3.25.0 final

* Wed Nov 09 2022 kekepower <kekepower> 1:3.25.0-0.rc4.1.mga9
+ Revision: 1904835
- Update to version 3.25.0-rc4

* Wed Nov 02 2022 kekepower <kekepower> 1:3.25.0-0.rc3.1.mga9
+ Revision: 1901452
- Update to version 3.25.0-rc3

* Thu Oct 20 2022 kekepower <kekepower> 1:3.25.0-0.rc2.1.mga9
+ Revision: 1897856
- Update to version 3.25.0-rc2

* Wed Oct 12 2022 kekepower <kekepower> 1:3.25.0-0.rc1.1.mga9
+ Revision: 1896641
- Update to version 3.25.0-rc1

* Wed Sep 14 2022 kekepower <kekepower> 1:3.24.2-1.mga9
+ Revision: 1888078
- Update to version 3.24.2

* Thu Aug 18 2022 kekepower <kekepower> 1:3.24.1-1.mga9
+ Revision: 1878480
- Update to version 3.24.1

* Fri Aug 05 2022 kekepower <kekepower> 1:3.24.0-1.mga9
+ Revision: 1875323
- Update to version 3.24.0 final

* Sat Jul 30 2022 kekepower <kekepower> 1:3.24.0-0.rc5.1.mga9
+ Revision: 1873216
- Update to version 3.24.0rc5

* Thu Jul 21 2022 kekepower <kekepower> 1:3.24.0-0.rc4.1.mga9
+ Revision: 1869704
- Update to version 3.24.0rc4

* Fri Jul 08 2022 kekepower <kekepower> 1:3.24.0-0.rc3.1.mga9
+ Revision: 1868024
- Update to version 3.24.0rc3

* Fri Jun 24 2022 kekepower <kekepower> 1:3.24.0-0.rc2.1.mga9
+ Revision: 1865659
- Update to version 3.24.0rc2

* Wed Jun 15 2022 kekepower <kekepower> 1:3.24.0-0.rc1.1.mga9
+ Revision: 1864470
- Update to version 3.24.0rc1

* Thu May 26 2022 kekepower <kekepower> 1:3.23.2-1.mga9
+ Revision: 1860196
- Update to version 3.23.2

* Wed Apr 13 2022 kekepower <kekepower> 1:3.23.1-1.mga9
+ Revision: 1849213
- Update to version 3.23.1

* Tue Mar 29 2022 kekepower <kekepower> 1:3.23.0-1.mga9
+ Revision: 1833136
- Update to version 3.23.0 final

* Thu Mar 24 2022 kekepower <kekepower> 1:3.23.0-0.rc5.1.mga9
+ Revision: 1825260
- Update to version 3.23.0-rc5

* Thu Mar 24 2022 umeabot <umeabot> 1:3.23.0-0.rc4.2.mga9
+ Revision: 1824084
- Mageia 9 Mass Rebuild

* Sat Mar 19 2022 kekepower <kekepower> 1:3.23.0-0.rc4.1.mga9
+ Revision: 1799784
- Update to version 3.23.0-rc4

* Fri Mar 11 2022 kekepower <kekepower> 1:3.23.0-0.rc3.1.mga9
+ Revision: 1790316
- Update to version 3.23.0-rc3

* Fri Feb 25 2022 kekepower <kekepower> 1:3.23.0-0.rc2.1.mga9
+ Revision: 1784534
- Update to version 3.23.0-rc2
+ wally <wally>
- provide cmake-gui with cmake-qtgui package

* Sat Dec 25 2021 wally <wally> 1:3.22.1-3.mga9
+ Revision: 1763654
- add upstream patches
  - FindBoost: Do not warn about now-supported version 1.78
  - FindBoost: Add support for Python 3.10

* Sun Dec 19 2021 wally <wally> 1:3.22.1-2.mga9
+ Revision: 1762758
- add upstream patch to add support for Boost 1.78

* Tue Dec 07 2021 kekepower <kekepower> 1:3.22.1-1.mga9
+ Revision: 1761038
- Update to version 3.22.1

* Fri Nov 19 2021 kekepower <kekepower> 1:3.22.0-1.mga9
+ Revision: 1757880
- Update to version 3.22.0 final

* Fri Nov 12 2021 wally <wally> 1:3.22.0-0.rc3.1.mga9
+ Revision: 1755941
- new version 3.22.0-rc3

* Thu Oct 28 2021 kekepower <kekepower> 1:3.22.0-0.rc2.1.mga9
+ Revision: 1753102
- Update to version 3.22.0-rc2

* Thu Oct 14 2021 kekepower <kekepower> 1:3.22.0-0.rc1.1.mga9
+ Revision: 1751465
- Update to version 3.22.0-rc1

* Tue Sep 21 2021 kekepower <kekepower> 1:3.21.3-1.mga9
+ Revision: 1746121
- Update to version 3.21.3

* Thu Aug 26 2021 kekepower <kekepower> 1:3.21.2-1.mga9
+ Revision: 1742572
- Update to version 3.21.2

* Wed Jul 28 2021 kekepower <kekepower> 1:3.21.1-1.mga9
+ Revision: 1737999
- Update to version 3.21.1

* Sat Jul 10 2021 wally <wally> 1:3.21.0-0.rc3.1.mga9
+ Revision: 1735597
- new version 3.21.0-rc3

* Thu Jul 01 2021 wally <wally> 1:3.21.0-0.rc2.1.mga9
+ Revision: 1734498
- new version 3.21.0 rc2

* Sun Jun 27 2021 wally <wally> 1:3.21.0-0.rc1.1.mga9
+ Revision: 1733997
- new version 3.21.0 rc1

* Tue Jun 22 2021 kekepower <kekepower> 1:3.20.5-1.mga9
+ Revision: 1731733
- Update to version 3.20.5

* Mon Jun 14 2021 kekepower <kekepower> 1:3.20.4-1.mga9
+ Revision: 1730794
- Update to version 3.20.4

* Fri May 28 2021 kekepower <kekepower> 1:3.20.3-1.mga9
+ Revision: 1728714
- Remove upstreamed patch
- Update to version 3.20.3

* Fri May 14 2021 wally <wally> 1:3.20.2-2.mga9
+ Revision: 1722918
- add upstream patch for Boost 1.76 support

* Thu Apr 29 2021 kekepower <kekepower> 1:3.20.2-1.mga9
+ Revision: 1720433
- Update to version 3.20.2

* Thu Apr 08 2021 kekepower <kekepower> 1:3.20.1-1.mga9
+ Revision: 1714133
- Update to version 3.20.1

* Wed Mar 24 2021 kekepower <kekepower> 1:3.20.0-2.mga9
+ Revision: 1708894
- Bump rel to fix arm build

* Wed Mar 24 2021 kekepower <kekepower> 1:3.20.0-1.mga9
+ Revision: 1708847
- Update to version 3.20.0 final

* Wed Mar 17 2021 kekepower <kekepower> 1:3.20.0-0.rc5.1.mga9
+ Revision: 1704170
- Update to version 3.20.0rc5

* Fri Mar 12 2021 kekepower <kekepower> 1:3.20.0-0.rc4.1.mga9
+ Revision: 1701660
- Update to version 3.20.0rc4

* Wed Mar 03 2021 kekepower <kekepower> 1:3.20.0-0.rc3.1.mga9
+ Revision: 1697495
- Update to version 3.20.0rc3

* Thu Feb 25 2021 kekepower <kekepower> 1:3.19.6-1.mga9
+ Revision: 1690179
- Update to version 3.19.6

* Tue Dec 22 2020 wally <wally> 1:3.19.2-2.mga8
+ Revision: 1662880
- add patch to fix cmake builds with FindGTK2 and atkmm

* Thu Dec 17 2020 kekepower <kekepower> 1:3.19.2-1.mga8
+ Revision: 1660084
- Update to version 3.19.2

* Sun Nov 29 2020 luigiwalser <luigiwalser> 1:3.19.1-2.mga8
+ Revision: 1650313
- rebuild for jsoncpp

* Tue Nov 24 2020 kekepower <kekepower> 1:3.19.1-1.mga8
+ Revision: 1649071
- Update to version 3.19.1

* Fri Nov 20 2020 kekepower <kekepower> 1:3.19.0-1.mga8
+ Revision: 1648021
- Update to version 3.19.0

* Wed Nov 18 2020 kekepower <kekepower> 1:3.18.5-1.mga8
+ Revision: 1647275
- Update to version 3.18.5

* Tue Oct 06 2020 kekepower <kekepower> 1:3.18.4-1.mga8
+ Revision: 1632459
- Update to version 3.18.4

* Wed Sep 23 2020 kekepower <kekepower> 1:3.18.3-1.mga8
+ Revision: 1629480
- Update to version 3.18.3

* Thu Aug 20 2020 kekepower <kekepower> 1:3.18.2-1.mga8
+ Revision: 1617031
- Update to version 3.18.2

* Fri Jul 31 2020 kekepower <kekepower> 1:3.18.1-1.mga8
+ Revision: 1610032
- Update to version 3.18.1

* Fri Jul 17 2020 wally <wally> 1:3.18.0-1.mga8
+ Revision: 1606706
- new version 3.18.0

* Wed Jul 08 2020 wally <wally> 1:3.18.0-0.rc3.2.mga8
+ Revision: 1603046
- new version 3.18.0-rc3

* Thu Jun 11 2020 joequant <joequant> 1:3.17.3-2.mga8
+ Revision: 1592505
- run bootstrap

* Thu May 28 2020 kekepower <kekepower> 1:3.17.3-1.mga8
+ Revision: 1588662
- Update to version 3.17.3

* Wed Apr 29 2020 kekepower <kekepower> 1:3.17.2-1.mga8
+ Revision: 1573127
- Update to version 3.17.2

* Fri Apr 10 2020 kekepower <kekepower> 1:3.17.1-1.mga8
+ Revision: 1565936
- Update to version 3.17.1

* Mon Mar 30 2020 wally <wally> 1:3.17.0-2.mga8
+ Revision: 1562452
- split out cmake rpm macros and scripts into cmake-rpm-macros src pkg

* Fri Mar 20 2020 kekepower <kekepower> 1:3.17.0-1.mga8
+ Revision: 1558335
- Update to version 3.17.0 final

* Sun Mar 15 2020 kekepower <kekepower> 1:3.17.0-0.rc3.1.mga8
+ Revision: 1556544
- Update to version 3.17.0-rc3

* Wed Mar 04 2020 kekepower <kekepower> 1:3.17.0-0.rc2.1.mga8
+ Revision: 1553614
- Update to version 3.17.0-rc2

* Thu Feb 27 2020 wally <wally> 1:3.17.0-0.rc1.1.mga8
+ Revision: 1551064
- new version 3.17.0-rc1

* Thu Feb 20 2020 umeabot <umeabot> 1:3.16.4-2.mga8
+ Revision: 1547340
- Mageia 8 Mass Rebuild

* Fri Feb 07 2020 kekepower <kekepower> 1:3.16.4-1.mga8
+ Revision: 1487921
- Update to version 3.16.4

* Wed Jan 29 2020 daviddavid <daviddavid> 1:3.16.3-2.mga8
+ Revision: 1484899
- add missing epoch on qtgui subpkg

* Wed Jan 22 2020 kekepower <kekepower> 1:3.16.3-1.mga8
+ Revision: 1482046
- Update to version 3.16.3

* Thu Jan 02 2020 wally <wally> 1:3.16.2-3.mga8
+ Revision: 1475592
- don't do bootstrap build if not needed
- use symlinks for emacs and vim files
- replace deprecated %%setup_compile_flags
- replace %%setup_compile_flags with upstream %%set_build_flags in %%cmake macro

* Wed Dec 25 2019 wally <wally> 1:3.16.2-2.mga8
+ Revision: 1470062
- update cmake.prov shebang explicitly to python3
- update %%cmake macro to use %%_vpath_builddir and %%_vpath_srcdir
- introduce %%cmake_build and %%cmake_install macros

* Fri Dec 20 2019 kekepower <kekepower> 1:3.16.2-1.mga8
+ Revision: 1469067
- Update to version 3.16.2

* Fri Dec 13 2019 kekepower <kekepower> 1:3.16.1-1.mga8
+ Revision: 1466151
- Update to version 3.16.1

* Sun Dec 08 2019 wally <wally> 1:3.16.0-1.mga8
+ Revision: 1465173
- new version 3.16.0

* Thu Oct 03 2019 daviddavid <daviddavid> 1:3.15.4-1.mga8
+ Revision: 1448977
- new version: 3.15.4

* Thu Sep 05 2019 daviddavid <daviddavid> 1:3.15.3-1.mga8
+ Revision: 1437459
- new version: 3.15.3

* Fri Aug 30 2019 tv <tv> 1:3.15.2-2.mga8
+ Revision: 1435552
- no reason to use non standard /etc/rpm/macro.d

* Thu Aug 08 2019 kekepower <kekepower> 1:3.15.2-1.mga8
+ Revision: 1428234
- Update to version 3.15.2

* Sat Jul 27 2019 daviddavid <daviddavid> 1:3.15.1-2.mga8
+ Revision: 1424468
- rebuild for arm

* Fri Jul 26 2019 daviddavid <daviddavid> 1:3.15.1-1.mga8
+ Revision: 1424412
- new version 3.15.1

* Thu Jul 18 2019 wally <wally> 1:3.15.0-1.mga8
+ Revision: 1422549
- new version 3.15.0
- drop old conflicts
- clean cmake rpm macros a tiny bit
- don't set CMAKE_SKIP_RPATH to ON by default

* Fri Jul 12 2019 daviddavid <daviddavid> 1:3.15.0-0.rc4.1.mga8
+ Revision: 1420533
- new version 3.15.0 rc4

* Fri Jul 05 2019 wally <wally> 1:3.15.0-0.rc3.1.mga8
+ Revision: 1418809
- new version 3.15.0 rc3

* Mon Apr 22 2019 kekepower <kekepower> 1:3.14.3-1.mga7
+ Revision: 1394745
- Update to version 3.14.3

* Fri Apr 12 2019 kekepower <kekepower> 1:3.14.2-2.mga7
+ Revision: 1389476
- Bump rel

* Fri Apr 12 2019 kekepower <kekepower> 1:3.14.2-1.1.mga7
+ Revision: 1389466
- Update to version 3.14.2

* Sat Mar 30 2019 wally <wally> 1:3.14.1-1.mga7
+ Revision: 1381679
- new version 3.14.1

* Sat Mar 30 2019 umeabot <umeabot> 1:3.14.0-2.mga7
+ Revision: 1381442
- Qt5 Rebuild

* Wed Mar 20 2019 shlomif <shlomif> 1:3.14.0-1.mga7
+ Revision: 1379278
- New version 3.14.0

* Sat Mar 02 2019 wally <wally> 1:3.13.4-2.mga7
+ Revision: 1371039
- define runstatedir with cmake rpm macro

* Mon Feb 04 2019 kekepower <kekepower> 1:3.13.4-1.mga7
+ Revision: 1363179
- Update to version 3.13.4

* Tue Jan 15 2019 kekepower <kekepower> 1:3.13.3-1.mga7
+ Revision: 1357206
- Update to version 3.13.3

* Mon Jan 14 2019 wally <wally> 1:3.13.2-2.mga7
+ Revision: 1356839
- update cmake rpm macros
  - drop unused _cmake_disable_intree_build
  - add _cmake_builddir and _cmake_sourcedir (originally from suse)
  - add ctest macro (originally from suse)

* Thu Dec 13 2018 kekepower <kekepower> 1:3.13.2-1.mga7
+ Revision: 1341036
- Update to version 3.13.2

* Wed Nov 28 2018 kekepower <kekepower> 1:3.13.1-1.mga7
+ Revision: 1336557
- Update to version 3.13.1

* Wed Nov 21 2018 kekepower <kekepower> 1:3.13.0-2.mga7
+ Revision: 1332560
- fix release
- Update to version 3.13.0

* Fri Nov 02 2018 kekepower <kekepower> 1:3.12.4-1.mga7
+ Revision: 1327764
- Update to version 3.12.4

* Wed Oct 03 2018 kekepower <kekepower> 1:3.12.3-1.mga7
+ Revision: 1317275
- Update to version 3.12.3

* Sun Sep 23 2018 wally <wally> 1:3.12.2-1.mga7
+ Revision: 1297195
- new version 3.12.2

* Sat Sep 22 2018 umeabot <umeabot> 1:3.12.1-2.mga7
+ Revision: 1296617
- Mageia 7 Mass Rebuild

* Sun Aug 26 2018 wally <wally> 1:3.12.1-1.mga7
+ Revision: 1254782
- new version 3.12.1

* Sun Aug 05 2018 wally <wally> 1:3.12.0-1.mga7
+ Revision: 1247708
- new version 3.12.0

* Fri Jun 15 2018 kekepower <kekepower> 1:3.11.4-1.mga7
+ Revision: 1236954
- Update to version 3.11.4

* Sat May 19 2018 wally <wally> 1:3.11.2-1.mga7
+ Revision: 1230492
- new version 3.11.2

* Sun Apr 22 2018 kekepower <kekepower> 1:3.11.1-2.mga7
+ Revision: 1220887
- Bump rel to rebuild on arm

* Sun Apr 22 2018 kekepower <kekepower> 1:3.11.1-1.mga7
+ Revision: 1220882
- Update to version 3.11.1

* Sun Apr 15 2018 wally <wally> 1:3.11.0-1.mga7
+ Revision: 1218953
- new version 3.11.0

* Fri Mar 23 2018 wally <wally> 1:3.11.0-0.rc4.1.mga7
+ Revision: 1211614
- new version 3.11.0-rc4

* Tue Feb 27 2018 neoclust <neoclust> 1:3.11.0-0.rc2.2.mga7
+ Revision: 1205589
- Rebuild with fixed BS
- New version 3.11.0 Rc2

* Mon Jan 29 2018 kekepower <kekepower> 1:3.10.2-1.mga7
+ Revision: 1197997
- Update to version 3.10.2
- Added an upstream patch to detect Boost 1.66.0

* Mon Jan 01 2018 wally <wally> 1:3.10.1-1.mga7
+ Revision: 1188832
- new version 3.10.1

* Sat Dec 09 2017 wally <wally> 1:3.10.0-1.mga7
+ Revision: 1181814
- new version 3.10.0

* Thu Nov 02 2017 neoclust <neoclust> 1:3.10.0-0.rc4.1.mga7
+ Revision: 1175470
- New version 3.10.0-rc4

* Sun Oct 22 2017 wally <wally> 1:3.10.0-0.rc3.1.mga7
+ Revision: 1173044
- new version 3.10.0 rc3

* Thu Oct 19 2017 mjack <mjack> 1:3.10.0-0.rc2.1.mga7
+ Revision: 1172697
- Updated to version 3.10.0 rc2

* Fri Oct 13 2017 eatdirt <eatdirt> 1:3.9.3-2.mga7
+ Revision: 1171523
- Rebuild for new jsoncpp

* Sun Oct 01 2017 wally <wally> 1:3.9.3-1.mga7
+ Revision: 1162104
- new version 3.9.3

* Fri Jul 21 2017 wally <wally> 1:3.9.0-1.mga7
+ Revision: 1125853
- new version 3.9.0

* Mon Jul 17 2017 neoclust <neoclust> 1:3.9.0-0.rc6.1.mga7
+ Revision: 1124502
- New version 3.9.0 RC6

* Fri Jun 09 2017 akien <akien> 1:3.7.2-3.mga6
+ Revision: 1107391
- Provide cmake3 to reduce diff with Fedora packaging

* Wed Jan 18 2017 wally <wally> 1:3.7.2-2.mga6
+ Revision: 1082329
- drop old enable_debug macro definitions from %%cmake macro

* Tue Jan 17 2017 wally <wally> 1:3.7.2-1.mga6
+ Revision: 1082162
- new version 3.7.2

* Mon Jan 02 2017 akien <akien> 1:3.7.1-2.mga6
+ Revision: 1079574
- Rebuild for libjsoncpp changed soname

* Sun Jan 01 2017 wally <wally> 1:3.7.1-1.mga6
+ Revision: 1079111
- new version 3.7.1
- BR libuv-devel

* Fri Dec 30 2016 wally <wally> 1:3.5.2-5.mga6
+ Revision: 1078690
- add %%_cmake_disable_intree_build macro and enable it by default for now (so we can later, maybe for mga7, disable it and do intree builds by default)

* Fri Dec 30 2016 wally <wally> 1:3.5.2-4.mga6
+ Revision: 1078662
- move non rpm related files to main pkg from cmake-rpm-macros

* Fri May 06 2016 neoclust <neoclust> 1:3.5.2-3.mga6
+ Revision: 1009750
- Split rpm macros / autoprov out of cmake main rpm

* Wed Apr 20 2016 daviddavid <daviddavid> 1:3.5.2-2.mga6
+ Revision: 1003695
- rebuild for arm due to an invalid build error

* Tue Apr 19 2016 daviddavid <daviddavid> 1:3.5.2-1.mga6
+ Revision: 1003612
- new version: 3.5.2

* Fri Mar 25 2016 neoclust <neoclust> 1:3.5.1-1.mga6
+ Revision: 995475
- New version 3.5.1

* Sat Mar 19 2016 wally <wally> 1:3.5.0-1.mga6
+ Revision: 992915
- new version 3.5.0
- drop unneeded Fix-FLTK-Find-path.patch

* Wed Jan 20 2016 wally <wally> 1:3.4.2-1.mga6
+ Revision: 926122
- new version 3.4.2

* Sun Jan 03 2016 wally <wally> 1:3.4.1-9.mga6
+ Revision: 919054
- remove '-O2 -g' (and only keep -DNDEBUG) from RELWITHDEBINFO flags, since this is already in our C[XX]FLAGS and would prevent overriding them (originally from blino)
- create %%_cmake_module_linker_flags rpm macro for the default CMAKE_MODULE_LINKER_FLAGS flags
- create %%_cmake_module_linker_flags_extra rpm macro for additional flags besides the default flags

* Sun Dec 27 2015 neoclust <neoclust> 1:3.4.1-8.mga6
+ Revision: 916150
- Add prov file back in cmake

* Sun Dec 27 2015 wally <wally> 1:3.4.1-7.mga6
+ Revision: 916026
- move cmake.prov and cmake.attr to rpm-mageia-setup-build

* Sun Dec 27 2015 wally <wally> 1:3.4.1-6.mga6
+ Revision: 915905
- find cmake() provides also from /usr/share/cmake/

* Sun Dec 27 2015 neoclust <neoclust> 1:3.4.1-5.mga6
+ Revision: 915855
- Use python2 for cmake() provides script as python3 is not in the chroot (wally)

* Sun Dec 27 2015 neoclust <neoclust> 1:3.4.1-4.mga6
+ Revision: 915728
- Add back skip rpath

* Sat Dec 26 2015 neoclust <neoclust> 1:3.4.1-3.mga6
+ Revision: 915116
- Rebuild with install fix
- Add cmake rpm auto-provide file
- Remove -DCMAKE_SKIP_RPATH:BOOL=ON from %%cmake macro

* Tue Dec 08 2015 wally <wally> 1:3.4.1-1.mga6
+ Revision: 908890
- new version 3.4.1
- pass -DCMAKE_VERBOSE_MAKEFILE:BOOL=ON by default to %%cmake macro

* Fri Nov 13 2015 neoclust <neoclust> 1:3.4.0-1.mga6
+ Revision: 903053
- New version 3.4.0

* Sun Nov 08 2015 wally <wally> 1:3.4.0-0.rc3.1.mga6
+ Revision: 898684
- new version 3.4.0 rc3

* Fri Oct 23 2015 wally <wally> 1:3.4.0-0.rc2.1.mga6
+ Revision: 894479
- new version 3.4.0 rc2

* Fri Oct 09 2015 wally <wally> 1:3.4.0-0.rc1.1.mga6
+ Revision: 888221
- new version 3.4.0 rc1
- force building packages with debug symbols (set the build type to RelWithDebInfo instead of Release with %%cmake macro)

* Fri Sep 18 2015 fwang <fwang> 1:3.3.2-1.mga6
+ Revision: 880303
- 3.3.2

* Fri Sep 11 2015 blino <blino> 1:3.3.1-5.mga6
+ Revision: 878311
- build qtgui with Qt5 instead of Qt4

* Wed Aug 26 2015 fwang <fwang> 1:3.3.1-4.mga6
+ Revision: 869529
- update url

* Thu Aug 13 2015 neoclust <neoclust> 1:3.3.1-3.mga6
+ Revision: 864547
- New version 3.3.1

* Wed Aug 12 2015 shlomif <shlomif> 1:3.3.0-3.mga6
+ Revision: 863463
- Rebuild for the new jsoncpp.
+ neoclust <neoclust>
- Rebuild against new jsoncpp-devel

* Mon Jul 27 2015 neoclust <neoclust> 1:3.3.0-1.mga6
+ Revision: 858221
- New version 3.3.0
- New version 3.3.0

* Wed Oct 15 2014 umeabot <umeabot> 1:3.0.1-5.mga5
+ Revision: 743426
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 1:3.0.1-4.mga5
+ Revision: 678449
- Mageia 5 Mass Rebuild

* Tue Aug 05 2014 neoclust <neoclust> 1:3.0.1-3.mga5
+ Revision: 659758
- Rebuild with file list fixed
- Add emacs support
- Add bash completion support
- Add vim config files
- New version 3.0.1

* Thu Apr 17 2014 wally <wally> 1:2.8.12.2-3.mga5
+ Revision: 615467
- define CMAKE_INSTALL_SYSCONFDIR in %%cmake macro

* Sat Feb 08 2014 fwang <fwang> 1:2.8.12.2-2.mga5
+ Revision: 586283
- recognize freetype 2.5

* Wed Feb 05 2014 fwang <fwang> 1:2.8.12.2-1.mga5
+ Revision: 583186
- new version 2.8.12.2

* Thu Nov 07 2013 blino <blino> 1:2.8.12.1-1.mga4
+ Revision: 549884
- 2.8.12.1

* Mon Oct 21 2013 umeabot <umeabot> 1:2.8.12-2.mga4
+ Revision: 541066
- Mageia 4 Mass Rebuild

* Fri Oct 11 2013 fwang <fwang> 1:2.8.12-1.mga4
+ Revision: 495028
- new version 2.8.12

* Thu Jul 04 2013 fwang <fwang> 1:2.8.11.2-1.mga4
+ Revision: 450031
- new version 2.8.11.2

* Fri Jun 28 2013 fwang <fwang> 1:2.8.11.1-2.mga4
+ Revision: 447739
- rebuild for new libarchive

* Mon Jun 10 2013 kamil <kamil> 1:2.8.11.1-1.mga4
+ Revision: 441870
- new version 2.8.11.1

* Mon Jun 03 2013 kamil <kamil> 1:2.8.11-3.mga4
+ Revision: 435580
- install bash-completion files: cmake, cpack, ctest

* Tue May 28 2013 fwang <fwang> 1:2.8.11-2.mga4
+ Revision: 429227
- detect new imagemaigck include dir

* Sun May 26 2013 neoclust <neoclust> 1:2.8.11-1.mga4
+ Revision: 428273
- New version 2.8.11

* Fri Jan 11 2013 umeabot <umeabot> 1:2.8.10.2-5.mga3
+ Revision: 347950
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sun Jan 06 2013 mitya <mitya> 1:2.8.10.2-4.mga3
+ Revision: 339729
- Provide LIBEXECDIR=%%{_libexecdir}

* Fri Dec 28 2012 mitya <mitya> 1:2.8.10.2-3.mga3
+ Revision: 335780
- Provide LIBEXECDIR=%%{_libdir}

* Mon Dec 17 2012 pterjan <pterjan> 1:2.8.10.2-2.mga3
+ Revision: 331959
- Support spaces in _smp_mflags

* Wed Nov 28 2012 fwang <fwang> 1:2.8.10.2-1.mga3
+ Revision: 322558
- new version 2.8.10.2

* Tue Nov 06 2012 mikala <mikala> 1:2.8.10-1.mga3
+ Revision: 314715
- Update tarball to final 2.8.10

* Sat Oct 27 2012 neoclust <neoclust> 1:2.8.10-0.rc3.1.mga3
+ Revision: 310598
- New version 2.9.10 rc3

* Sat Aug 11 2012 neoclust <neoclust> 1:2.8.9-1.mga3
+ Revision: 280564
- New version 2.8.9 Final

* Thu Aug 09 2012 neoclust <neoclust> 1:2.8.9-0.rc3.1.mga3
+ Revision: 280075
- New version 2.8.9-rc3

* Fri Jun 08 2012 fwang <fwang> 1:2.8.8-1.mga3
+ Revision: 257642
- new version 2.8.8

* Sun Feb 26 2012 shlomif <shlomif> 1:2.8.7-5.mga2
+ Revision: 215381
- Updated cmake-2.8.4-xz patch from the Mandriva repository. Applying it again.

* Mon Jan 23 2012 dmorgan <dmorgan> 1:2.8.7-4.mga2
+ Revision: 200174
- Own %%_libdir/%%name

* Tue Jan 17 2012 mikala <mikala> 1:2.8.7-3.mga2
+ Revision: 197113
- Remove ugly patch done by me to restore boost detection (the error was in boost packaging)

* Wed Jan 04 2012 fwang <fwang> 1:2.8.7-2.mga2
+ Revision: 190635
- rebuild for new libarchive

* Sat Dec 31 2011 fwang <fwang> 1:2.8.7-1.mga2
+ Revision: 189268
- new version 2.8.7

* Sun Oct 09 2011 fwang <fwang> 1:2.8.6-1.mga2
+ Revision: 153428
- new version 2.8.6

* Wed Sep 28 2011 fwang <fwang> 1:2.8.6-0.rc4.1.mga2
+ Revision: 149962
- new version 2.8.6 rc4

* Wed Sep 14 2011 fwang <fwang> 1:2.8.6-0.rc3.2.mga2
+ Revision: 143569
- fix pthread detection

* Sat Sep 10 2011 fwang <fwang> 1:2.8.6-0.rc3.1.mga2
+ Revision: 142167
- new version 2.8.6 rc3

* Thu Sep 08 2011 mikala <mikala> 1:2.8.6-0.rc2.2.mga2
+ Revision: 140979
- Add patch3 to reverse for the moment a change regarding FindBoost.cmake module (which prevent findings boost librairies)

* Wed Sep 07 2011 dmorgan <dmorgan> 1:2.8.6-0.rc2.1.mga2
+ Revision: 140712
- Remove file moving, the files does not exist anymore
- New version 2.8.6 rc2
- New version 2.8.6-rc1
+ tv <tv>
- fix %%install
- fix file list

* Sat Jul 09 2011 ahmad <ahmad> 1:2.8.5-1.mga2
+ Revision: 120929
- Update to 2.8.5

* Thu Jul 07 2011 ahmad <ahmad> 1:2.8.5-0.rc3.1.mga2
+ Revision: 119742
- Update to 2.8.5-rc3
- Change the spec to make it easier to package rc's
+ kharec <kharec>
- just clean the top of spec by tabs, no need to increment rel.

* Tue Mar 15 2011 ahmad <ahmad> 1:2.8.4-1.mga1
+ Revision: 72094
- update to 2.8.4

* Fri Feb 11 2011 ahmad <ahmad> 1:2.8.3-4.mga1
+ Revision: 49945
- drop py27 patch, fixed upstream
- use current qt4 Epoch in the qt4-devel BR
- remove the mydocs hack, %%doc macro was fixed ages ago

* Sun Jan 16 2011 dmorgan <dmorgan> 1:2.8.3-3.mga1
+ Revision: 20018
- Rebuild with new cmake

* Fri Jan 14 2011 dmorgan <dmorgan> 1:2.8.3-2.mga1
+ Revision: 17381
- Bump release
- Rebuild cmake with qt4 support now

* Tue Jan 11 2011 dmorgan <dmorgan> 1:2.8.3-1.mga1
+ Revision: 6287
- Do not build qtgui for now
+ ahmad <ahmad>
- drop old scriptlets and conflicts
- require rpm-magei-setup
- imported package cmake

